#!/bin/sh
# Author: serge.d3@free.fr 
# License: GPL 2.0
# Ver.: 0.2.0

SERVICEMENU="krpm2info"
KDE_LOCAL=`kde-config --localprefix`
KDE_GLOBAL=`kde-config --prefix`

function Uninstall () {
echo -ne "   Removing [$SERVICEMENU] in: $KDE/apps/$SERVICEMENU..."
if [ ! "$UID" == "0" ]; then
   rm -f $HOME/bin/$SERVICEMENU
fi
rm -rf $KDE/apps/$SERVICEMENU
rm -f $KDE/share/applnk/System/Configuration/Packaging/$SERVICEMENU.desktop
rm -f $KDE/share/apps/konqueror/servicemenus/$SERVICEMENU-servicemenu.desktop
echo "...   [ OK ]"; echo ""
}

function Install () {
echo -ne "   Installing [$SERVICEMENU] in: $KDE/apps/$SERVICEMENU..."
mkdir -p $KDE/share/apps/konqueror/servicemenus/
mkdir -p $KDE/share/applnk/System/Configuration/Packaging/
mkdir -p $KDE/share/apps/$SERVICEMENU/icons/
if [ ! "$UID" == "0" ]; then
   if [ ! -d $HOME/bin ]; then
      echo "   *Creating $HOME/bin"
      echo "   *Adding path:[$HOME/bin:$PATH]"
      mkdir -p $HOME/bin/
      echo "export PATH=$HOME/bin:$PATH" >> $HOME/.bashrc
   fi
   cp -f $SERVICEMENU $HOME/bin/$SERVICEMENU
else
   cp -f $SERVICEMENU $KDE/bin/$SERVICEMENU
fi
cp -f ./icons/* $KDE/share/apps/$SERVICEMENU/icons/
cp -f $SERVICEMENU-servicemenu.desktop $KDE/share/apps/konqueror/servicemenus/
cp -f $SERVICEMENU.desktop $KDE/share/applnk/System/Configuration/Packaging/
echo "...   [ OK ]"; echo ""
}

function Config () {
if [ -f "/etc/issue" ]; then
   [ -n "`grep '[Mm][Aa][Nn][Dd][Rr]' /etc/issue`" ] && TYPE="mandrake" # Mandrake
   [ -n "`grep '[Ff][Ee][Dd][Oo][Rr][Aa]' /etc/issue`" ] && TYPE="fedora" # Fedora
   [ -n "`grep '[Ss][Uu][Ss][Ee]' /etc/issue`" ] && TYPE="suse" # SuSE
   [ -n "`grep '[Cc][Oo][Nn][Ee][Cc][Tt][Ii][Vv][Aa]' /etc/issue`" ] && TYPE="conectiva" # Conectiva Linux 
   [ -n "`grep 'PLD' /etc/issue`" ] && TYPE="Polish" #  Polish(ed) Linux Distribution
   [ -n "$TYPE" ] && TYPE_MSG="( for System $TYPE )"
fi
APPLNK="$KDE/share/applnk/System/Configuration/Packaging/$SERVICEMENU.desktop"
cat <<EOF > $APPLNK
[Desktop Entry]
Comment[fr]=Gérer les fichiers RPM.
Encoding=UTF-8
Exec=krpm2info %f
GenericName=K Rpm2Info
GenericName[fr]=K Rpm2Info (Trousse à outils RPM)
Icon= $KDE/share/apps/$SERVICEMENU/icons/$SERVICEMENU.png
InitialPreference=10
MimeType=application/x-rpm
Name=K Rpm2Info
Name[fr]=K Rpm2Info (Trousse à outils RPM)
Path=
StartupNotify=true
Terminal=false
TerminalOptions=
Type=Application
X-DCOP-ServiceType=
X-KDE-SubstituteUID=false
X-KDE-Username=
Actions=find_rediris;find_rpmfind;find_pbone

[Desktop Action find_rpmfind]
Icon=find
Name=Go "RpmFind" Home Page...
Exec=kfmclient newTab http://rpmfind.net/linux/rpm2html/search.php?query=&submit=Search+...&system=$TYPE

[Desktop Action find_rediris]
Icon=find
Name=Go "RedIris" Home Page...
Exec=kfmclient newTab http://rpmfind.rediris.es/linux/rpm2html/search.php?query=&submit=Search+...&system=$TYPE

[Desktop Action find_pbone]
Icon=find
Name=Go "pBone" Home Page...
Exec=kfmclient newTab http://rpm.pbone.net/
EOF
if [ -f "$APPLNK" ]; then
   echo "   *Adding applnk $TYPE_MSG."; echo ""
fi
}

clear
echo " General Information"
echo " =============="
echo "A service menu (krpm2info-servicemenu.desktop) for Konqueror that works in "
echo "conjunction  with a bash script (krpm2info) to allow several actions on package RPM:"
echo "   -Extract: To extract the contents from package RPM in a new dir and to post "
echo "    in a page HTML information of file RPM."
echo "   -About: : Post in a page HTML information of file RPM."
echo "   -Research on RpmFind: Seek file RPM on RpmFind."
echo "   -Research on RedIris: Seek file RPM on RedIris."
echo "   -Research on pBone: Seek file RPM on pBone."
echo ""   

echo " Requirements"
echo " =========="
echo "KDE 3.3"
echo "Qt 3.2"
echo "rpm2cpio"
echo "rpm 4.2"
echo ""

echo " Authors"
echo " ======"
echo "Serge (serge.d3@free.fr)"
echo ""

echo " Installation"
echo " ========"
echo "You need rpm2cpio, KDE, QT and rpm in your path:"

if [ -x "`which rpm2cpio`" ] && [ "`rpm --version 2>/dev/null | grep "4.2."`" ] && [ "`kde-config --version 2>/dev/null | grep "3.3"`" ]; then
   echo "`which rpm2cpio`" 
   echo "`rpm --version`"
   echo "`kde-config --version`"
else 
   echo "Sorry..."
   echo "rpm2cpio: `which rpm2cpio`"
   echo "rpm: `rpm --version 2>/dev/null`"
   echo "KDE / QT: `kde-config --version 2>/dev/null`"
   exit 0
fi

echo ""
echo "Select action:"
echo " 1 - Now installing $SERVICEMENU"
echo " 2 - Removing $SERVICEMENU"
echo " 0 - Quit the installer"
echo -n "Select options 1, 2 or 0 to quit: "
read num
if [ "$num" = "0" ]; then
    exit 0
fi
case "$num" in
    1)
       if [ "`echo $UID`" == "0" ]; then
          KDE=$KDE_GLOBAL
       else
          KDE=$KDE_LOCAL
       fi
       Install
       Config
       ;;
     2)
       if [ "`echo $UID`" == "0" ]; then
          KDE=$KDE_GLOBAL
       else
          KDE=$KDE_LOCAL
       fi
       Uninstall
       ;;
 esac
 exit 0
